# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

<!--
The rules for this file:
  * entries are sorted newest-first.
  * summarize sets of changes - don't reproduce every git log comment here.
  * don't ever delete anything.
  * keep the format consistent:
    * do not use tabs but use spaces for formatting
    * 79 char width
    * YYYY-MM-DD date format (following ISO 8601)
  * accompany each entry with github issue/PR number (Issue #xyz)
-->

## [Unreleased]

### Authors
- @fiona-naughton

### Added
<!-- New added features -->
* Core functionality, tests and documentation were implemented
using the code from `MDAnalysis.analysis.helix_analysis`

### Fixed
<!-- Bug fixes -->

### Changed
* Overhaul of documentation 

### Deprecated
<!-- Soon-to-be removed features -->

### Removed
<!-- Removed features -->

## Prior to relocation as MDAKit
helanal was created from existing code in the MDAnalysis core library. 
Changes made to this code prior its transfer to stand-alone MDAKit can
be found in the CHANGELOG for [MDAnalysis](https://github.com/MDAnalysis/mdanalysis/blob/develop/package/CHANGELOG). 

